@@ -14,7 +14,8 @@ ClusterComponentUpdate <- function(dpObj){
   UseMethod("ClusterComponentUpdate", dpObj)
 }
 
-#'@export
+#' @export
+#' @rdname ClusterComponentUpdate
 ClusterComponentUpdate.conjugate <- function(dpObj) {
 
   y <- dpObj$data
@@ -39,7 +40,8 @@ ClusterComponentUpdate.conjugate <- function(dpObj) {
 
     probs <- c(
       pointsPerCluster * Likelihood(mdObj, y[i, , drop = FALSE], clusterParams),
-      alpha * predictiveArray[i])
+      alpha * predictiveArray[i]
+      )
 
     probs[is.na(probs)] <- 0
 
@@ -141,7 +143,9 @@ ClusterComponentUpdate.nonconjugate <- function(dpObj) {
   dpObj$numberClusters <- numLabels
   return(dpObj)
 }
-#'@export
+
+#' @export
+#' @rdname ClusterComponentUpdate
 ClusterComponentUpdate.hierarchical <- function(dpObj){
 
   for(i in seq_along(dpObj$indDP)){
